@@ -19,4 +19,4 @@ def call(trigger, params=None):
                 else:
                     event["event"](params)
     except Exception as e:
-        logger.log("§cEvent Exception: " + str(e))
\ No newline at end of file
+        logger.log("§cEvent '" + trigger + "' throw exception: " + str(e))
\ No newline at end of file
