@@ -30,13 +30,21 @@ class Client:
         def clientTask():
             if self.error == 0:
                 self.send({"METHOD": "AUTHENTICATION", "CLIENT_ID": self.clientID, "CLIENT_TYPE": self.clientType, "PASSWORD": self.password})
+            lastData = ""
             while self.error == 0:
-                lastData = "None"
                 try:
                     recvData = self.clientSocket.recv(32768)
                     recvData = str(recvData, "utf-8")
                     if recvData != "":
-                        lastData = recvData
+                        if not recvData.startswith("{"):
+                            if recvData.endswith("}" + self.seq):
+                                if lastData != "":
+                                    recvData = lastData + recvData
+                                    logger.log("§8[§eSERVER§8] §8[§cWARNING§8] §cUnsigned data repaired")
+                        if not recvData.endswith("}" + self.seq):
+                            lastData += recvData
+                            logger.log("§8[§eSERVER§8] §8[§cWARNING§8] §cReceiving unsigned data: §r" + recvData)
+                            continue
                         if "}" + self.seq + "{" in recvData:
                             recvDataList = recvData.split("}" + self.seq + "{")
                             recvData = "["
@@ -45,11 +53,10 @@ class Client:
                                 if i + 1 < len(recvDataList):
                                     recvData += "}, {"
                             recvData += "]"
+                            lastData = ""
                         elif "}" + self.seq in recvData:
                             recvData = "[" + recvData.replace(self.seq, "") + "]"
-                        else:
-                            logger.log("§8[§eSERVER§8] §8[§cWARNING§8] §cNot authenticated data: " + recvData)
-                            continue
+                            lastData = ""
                         recvData = json.loads(recvData)
                         for data in recvData:
                             if data["METHOD"] == "AUTHENTICATION_FAILED":
@@ -64,10 +71,10 @@ class Client:
                             else:
                                 if data["METHOD"] not in self.packagePrintBlacklist:
                                     logger.log("§8[§eCLIENT§8] §r[IN] " + data["METHOD"])
-                                events.call("ON_RECEIVE", params=[self, data])
+                                events.call("ON_RECEIVE", params=[data])
                 except Exception as e:
                     self.error = 1
-                    logger.log("§8[§eCLIENT§8] §8[§cWARNING§8] §cException: " + str(e) + " while receiving: " + lastData)
+                    logger.log("§8[§eCLIENT§8] §8[§cWARNING§8] §cException: §4" + str(e))
                     break
             self.clientSocket.close()
             self.connected = False
